@@ -5,6 +5,13 @@ from cognite.air._backfilling_api import AIRBackfillingAPI, NoBackfillAPI
 from cognite.air._config import AIRClientConfig
 from cognite.air._events_api import AIREventsAPI
 from cognite.air._time_series_api import AIRTimeSeriesAPI
+from cognite.air._utils import (
+    get_local_testing,
+    retrieve_backfilling,
+    retrieve_field_definitions,
+    retrieve_model_name,
+    retrieve_model_version,
+)
 from cognite.air.constants import (
     AIR_TYPES,
     LEGAL_FIELD_TYPES,
@@ -23,26 +30,60 @@ from cognite.client.data_classes import Asset, TimeSeries
 class AIRClient:
     def __init__(self, data: Dict[str, Any], client: CogniteClient, secrets: Dict[str, Any], debug: bool = False):
         del secrets  # Unused for now (required in function signature)
-        sa_ext_id = self._extract_and_validate_sa_ext_id(data)
-        schedule_asset = self._retrieve_and_verify_schedule_asset(client, sa_ext_id)
-        model_asset = self._retrieve_and_verify_model_asset(client, schedule_asset.parent_external_id)
-        model_version = model_asset.metadata[MA_FIELD_META_MODELVERSION]
-        # Retrieve backfilling asset if the model uses backfilling:
+        self._testing = get_local_testing(data)
         backfilling_asset = None
-        if is_string_truthy(model_asset.metadata.get("backfill")):
-            backfilling_asset = self._retrieve_and_verify_backfill_asset(client, sa_ext_id, model_version)
+        if not self._testing:
+            sa_ext_id = self._extract_and_validate_sa_ext_id(data)
+            schedule_asset = self._retrieve_and_verify_schedule_asset(client, sa_ext_id)
+            model_asset = self._retrieve_and_verify_model_asset(client, schedule_asset.parent_external_id)
+            model_version = model_asset.metadata[MA_FIELD_META_MODELVERSION]
+            # Retrieve backfilling asset if the model uses backfilling:
+            if is_string_truthy(model_asset.metadata.get("backfill")):
+                backfilling_asset = self._retrieve_and_verify_backfill_asset(client, sa_ext_id, model_version)
 
-        self._config = AIRClientConfig(
-            client=client,
-            data_set_id=schedule_asset.data_set_id,
-            schedule_asset=schedule_asset,
-            schedule_asset_id=schedule_asset.id,
-            schedule_asset_ext_id=sa_ext_id,
-            data_fields=parse_json_if_json(schedule_asset.metadata.get(SA_FIELD_META_DATA)) or {},
-            data_fields_defs=self.create_data_field_dct(model_asset.metadata.get(MA_FIELD_META_FIELDS)),
-            model_name=model_asset.name,
-            model_version=model_version,
-        )
+            self._config = AIRClientConfig(
+                client=client,
+                data_set_id=schedule_asset.data_set_id,
+                schedule_asset=schedule_asset,
+                schedule_asset_id=schedule_asset.id,
+                schedule_asset_ext_id=sa_ext_id,
+                data_fields=parse_json_if_json(schedule_asset.metadata.get(SA_FIELD_META_DATA)) or {},
+                data_fields_defs=self.create_data_field_dct(model_asset.metadata.get(MA_FIELD_META_FIELDS)),
+                model_name=model_asset.name,
+                model_version=model_version,
+            )
+
+        else:
+            model_version = retrieve_model_version()
+            sa_ext_id = "ScheduleAssetTestExtId"
+            model_name = retrieve_model_name()
+            fake_data_set_id = 123
+            fake_schedule_asset_id = 123
+            fake_backfill_completed = data.get("backfill_completed", "False")
+            fake_backfilled_until = data.get("backfilled_until", "0")
+
+            if is_string_truthy(retrieve_backfilling()) and is_string_truthy(data.get("backfilling")):
+                backfilling_asset = self.create_fake_backfilling_asset(
+                    model_name,
+                    fake_schedule_asset_id,
+                    sa_ext_id,
+                    fake_data_set_id,
+                    fake_backfill_completed,
+                    fake_backfilled_until,
+                    model_version,
+                )
+
+            self._config = AIRClientConfig(
+                client=client,
+                data_set_id=fake_data_set_id,
+                schedule_asset=Asset(),
+                schedule_asset_id=fake_schedule_asset_id,
+                schedule_asset_ext_id=sa_ext_id,
+                data_fields=data,
+                data_fields_defs=self.create_data_field_dct(retrieve_field_definitions()),
+                model_name=model_name,
+                model_version=model_version,
+            )
         self.events = AIREventsAPI(self._config)
         self.time_series = AIRTimeSeriesAPI(self._config)
         self.backfilling = NoBackfillAPI()
@@ -51,7 +92,7 @@ class AIRClient:
             if backfilling.in_progress:
                 self.backfilling = backfilling  # type: ignore
 
-        if debug:
+        if debug or self._testing:
             print(
                 f"Tenant: {client.config.project}\nSchedule asset ext. ID: {self._config.schedule_asset_ext_id}\n"
                 f"Model name: {self._config.model_name}\nModel version: {self._config.model_version}\n"
@@ -86,8 +127,7 @@ class AIRClient:
     def schedule_front_end_name(self):
         return self._config.schedule_asset.metadata.get(MA_FIELD_META_MTNAME)
 
-    @schedule_front_end_name.setter
-    def schedule_front_end_name(self, name):
+    def set_schedule_front_end_name(self, name):
         if name != self.schedule_front_end_name:
             self._config.schedule_asset.metadata[MA_FIELD_META_MTNAME] = name
             self.cognite_client.assets.update(self._config.schedule_asset)
@@ -96,8 +136,7 @@ class AIRClient:
     def schedule_front_end_description(self):
         return self._config.schedule_asset.metadata.get(MA_FIELD_META_MTDESCRIPTION)
 
-    @schedule_front_end_description.setter
-    def schedule_front_end_description(self, description):
+    def set_schedule_front_end_description(self, description):
         if description != self.schedule_front_end_description:
             self._config.schedule_asset.metadata[MA_FIELD_META_MTDESCRIPTION] = description
             self.cognite_client.assets.update(self._config.schedule_asset)
@@ -202,3 +241,31 @@ class AIRClient:
         raise AIRClientError(
             f"Found {len(backfill_asset_list)} backfilling asset(s). Expected exactly 1 backfilling asset"
         )
+
+    @staticmethod
+    def create_fake_backfilling_asset(
+        model_name: str,
+        schedule_asset_id: int,
+        schedule_asset_ext_id: str,
+        data_set_id: int,
+        backfill_complete: str,
+        backfilled_until: str,
+        model_version: str,
+    ):
+        bf_asset_dict = {
+            "external_id": "bf1234",
+            "name": f"{model_name} backfill",
+            "parent_id": schedule_asset_id,
+            "parent_external_id": schedule_asset_ext_id,
+            "data_set_id": data_set_id,
+            "metadata": {
+                "backfill_complete": backfill_complete,
+                "backfilled_until": backfilled_until,
+                "call_lock": "1234",
+                "model": schedule_asset_id,
+                "version": model_version,
+            },
+            "id": 123456,
+            "root_id": 6789,
+        }
+        return Asset(**bf_asset_dict)
