@@ -7,6 +7,8 @@ SA_EXT_ID = "schedule_asset_ext_id"
 SA_FIELD_META_DATA = "data"
 MA_FIELD_META_FIELDS = "fields"
 MA_FIELD_META_MODELVERSION = "modelVersion"
+MA_FIELD_META_MTNAME = "monitoring_task_name"
+MA_FIELD_META_MTDESCRIPTION = "monitoring_task_description"
 
 # Constants related to CDF Event and Time Series resources:
 EVENT_EXT_ID = "external_id"
@@ -47,6 +49,7 @@ class AIREventMeta:
 
 AIR_TS_FIELD_DATASET = "data_set_id"
 AIR_TS_FIELD_METADATA = "metadata"
+AIR_MT_META_KEY_MODEL_NAME = "model"
 AIR_TS_META_KEY_MODEL_VERSION = "model_version"
 AIR_TS_META_KEY_SCHEDULE_ASSET_ID = SA_EXT_ID
 
